# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 错误消息统一管理
# @Time   : 2024-02-01 10:00
# @Author : 毛鹏
ERROR_MSG_0001 = (3001, 'mysql链接错误，请检查服务器是否可以链接到这个地址，或是IP端口账号密码错误')
ERROR_MSG_0002 = (3002, '无法获取缓存的key【{}】的值，请检查是否设置这个key')
ERROR_MSG_0003 = (3003, 'jsonpath表达式错误或响应中不包含取的值，jsonpath：【{}】')
ERROR_MSG_0004 = (3004, '数据不可以被转换成json')
ERROR_MSG_0006 = (3006, '随机字符串函数只支持传入int类型数字')
ERROR_MSG_0033 = (3033, 'mysql中无：【{}】库')
ERROR_MSG_0034 = (3034, 'sql存在语法错误，请检查sql语句：{}，错误信息：{}')
ERROR_MSG_0035 = (3035, 'sql语句是空，或查询字段或条件字段不存在')
ERROR_MSG_0047 = (3047, '随机数据方法不存在，请检查输入的方法名称是否正确，方法名称：{}，错误类型：{}')
ERROR_MSG_0061 = (3061, '前置或者后置的自定义函数没有按照文档规范填写，或者语法不正确，请参照文档后重新填写')
ERROR_MSG_0014 = (3014, '企微发送失败，请检查企微发送配置')
ERROR_MSG_0015 = (3015, '的类型错误，请联系管理员进行排查问题')
ERROR_MSG_0016 = (3016, '邮件发送失败，请检查邮件的配置')
ERROR_MSG_0017 = (3017, '断言失败，提示： 【{}】')
ERROR_MSG_0018 = (3018, 'webhook的链接错误！')
ERROR_MSG_0019 = (3019, '文件断言必须要使用可以被序列化为json格式数据')
ERROR_MSG_0020 = (3020, 'SQL断言的期望值必须要使用可以被序列化为json格式数据')
ERROR_MSG_0021 = (3021, 'SQL断言必须要传入SQL链接对象')
ERROR_MSG_0022 = (3022, '请根据帮助文档，传入函数需要的参数个数，不要多传或少传')
ERROR_MSG_0023 = (3023, '传入的函数不合法，请参考帮助文档')
ERROR_MSG_0024 = (3024, '提交到git仓库时，未提供有效的身份信息')
